---
title: <span class="badge object-type-scalar"></span> UruguayPeso
---
# <span class="badge object-type-scalar"></span> UruguayPeso

Currency: Uruguay Peso (UYU)

## Definition

```python
# Currency: Uruguay Peso (UYU)
UruguayPeso: typing.Literal["currencyUYU"] = "currencyUYU"
```
